@@ -10,8 +10,8 @@ MeanStaDist<-function(Ldat)
     
     MLAT = median(lat, na.rm = TRUE)
     MLON = median(lon)
-    proj = setPROJ(type=2, LAT0=MLAT, LON0=MLON)
-    XY = GLOB.XY(lat, lon, proj)
+    proj = GEOmap::setPROJ(type=2, LAT0=MLAT, LON0=MLON)
+    XY = GEOmap::GLOB.XY(lat, lon, proj)
     DXY = dist(cbind(XY$x, XY$y))
     Mdistwt = mean(DXY)
     return(Mdistwt)
