@@ -13,13 +13,13 @@ getresidTT<-function(Ldat,EQ, stas , vel)
    MLAT = median(Ldat$lat)
    MLON = median(Ldat$lon)
 
-   proj = setPROJ(type=2, LAT0=MLAT, LON0=MLON)
+   proj = GEOmap::setPROJ(type=2, LAT0=MLAT, LON0=MLON)
 
-   XY = GLOB.XY(Ldat$lat, Ldat$lon, proj)
+   XY = GEOmap::GLOB.XY(Ldat$lat, Ldat$lon, proj)
    Ldat$x = XY$x
    Ldat$y = XY$y
 
-   eqxy = GLOB.XY(EQ$lat, EQ$lon, proj)
+   eqxy = GEOmap::GLOB.XY(EQ$lat, EQ$lon, proj)
    EQ$x = eqxy$x
    EQ$y =  eqxy$y
    
